// production webpack configuration
const path = require('path');
const { merge } = require('webpack-merge');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const webpackBaseConfig = require('./webpack.base');

const hot = [];

const entry = {
  index: hot.concat(require.resolve('../src/index.ts')),
};

const htmlWebpackPlugin = Object.keys(entry).map(
  name =>
    new HtmlWebpackPlugin({
      inject: 'body',
      scriptLoading: 'defer',
      template: path.join(__dirname, '../template/index.html'),
      minify: false,
      filename: `${name}.html`,
      chunks: [name],
    }),
);

module.exports = merge(webpackBaseConfig, {
  mode: 'production',
  entry,
  output: {
    publicPath: './',
    filename: '[name].js',
    library: 'elgo-rich',
    libraryTarget: 'umd',
    umdNamedDefine: true,
    // libraryExport: 'default',
  },
  externals: {
    'draft-js': 'draft-js',
  },
  resolve: {
    alias: {
      react: path.resolve(__dirname, '../node_modules/react'),
      'react-dom': path.resolve(__dirname, '../node_modules/react-dom'),
    },
  },
  module: {
    rules: [
      {
        test: /.s?css$/,
        use: [MiniCssExtractPlugin.loader, 'css-loader', 'sass-loader'],
      },
    ],
  },
  plugins: [new MiniCssExtractPlugin(), ...htmlWebpackPlugin],
  optimization: {
    minimize: true,
    minimizer: [new CssMinimizerPlugin()],
    splitChunks: {
      cacheGroups: {
        commons: {
          test: /(react|react-dom)/,
          name: 'vendors',
          chunks: 'all',
        },
      },
    },
  },
});
